import React, { useEffect, useState } from "react";
import { Col, Row, Button } from "react-bootstrap";
import favoriteDataAccess from "dataAccess/favoriteDataAccess";
import SpinnerLocal from "components/spinner";
import { connect, useDispatch } from "react-redux";
import { actions as favoriteActions } from "@redux/favoriteRedux";
import { actions as cartActions } from "@redux/cartRedux";
import cartServices from "services/cartServices";
import { Favorite } from "models/favorite";
import favoriteServices from "services/favouriteServices";
import { isUserLoggedIn } from "services/userServices";
import { Helmet } from "react-helmet";
import SliderDataAccess from "dataAccess/sliderDataAccess";
import { toast } from "react-toastify";
import {FiTrash} from "react-icons/fi";

const FavoriteProductList = (props) => {
  const dispatch = useDispatch();

  const [status, setStatus] = useState(null);

  const [currency, setCurrency] = useState(null);
  useEffect(() => {
    SliderDataAccess.getSettingData()
      .then((data) => {
        setCurrency(data.currency_symbol);
      })
      .catch((error) => {});
  }, []);

  useEffect(() => {
    dispatch(favoriteActions.getFavoriteProducts(props.favorite.favorite));
  }, [dispatch, props.favorite.favorite]);
  if (props.favorite.favorite.length !== props.favorite.products.length) {
    return <SpinnerLocal height="70vh"/>;
  }
  if (props.favorite.productsError) {
    return <div>Something went wrong</div>;
  }
  const addAllToCart = () => {
    let _data = [];
    props.favorite.favorite.forEach((favoriteItem: Favorite, index: number) => {
      if (!cartServices.isProductOnCart(favoriteItem.id, props.cart.cart)) {
        _data.push({ id: favoriteItem.id, quantity: 1 });
      }
    });
    dispatch(
      cartActions.addAllProductsToCart(_data, isUserLoggedIn(props.user.user))
    );
  };
  return (
    <div className="user-profile-top">
      <Helmet>
        <title> Genx | Favorite </title>
        <meta name="description" content="My Favorite Products" />
      </Helmet>
      <div className="create-account-container contact-us-bottom profile-bottom">
        <Row>
          <Col className="sideNav">
            <Row className="favorite-container">
              <Col
                xl={12}
                lg={12}
                md={12}
                sm={12}
                xs={12}
                className="first-section"
              >
                <div>
                  <span className="header"> My Favorite </span>
                </div>
              </Col>
              <hr style={{ width: "100%" }} />
              <Col
                xl={12}
                lg={12}
                md={12}
                sm={12}
                xs={12}
                className="second-section"
              >
                {props.favorite.products &&
                props.favorite.products.length > 0 ? (
                  props.favorite.favorite.map((favorite: Favorite, index) => {
                    const product = favoriteServices.getFavoriteProduct(
                      favorite,
                      props.favorite.products
                    );
                    return (
                      <Row className="content">
                        <Col xl={6} lg={6} md={12} sm={12} xs={12}>
                          <div className="d-flex align-items-center">
                            <div className="px-3">
                              <img
                                  src={product.image1}
                                  className="left-img-circle"
                                  alt=""
                              />
                            </div>
                            <div>
                              <h6 className="">{product.name}</h6>{" "}
                            </div>
                          </div>
                          {/*<Row>*/}
                          {/*  <Col xs="auto">*/}

                          {/*  </Col>*/}
                          {/*  <Col xs="auto">*/}
                          {/*    <h4 className="name-and-unit">{product.name}</h4>{" "}*/}
                          {/*    /!* <span> {product.unit.name} </span> *!/*/}
                          {/*  </Col>*/}
                          {/*</Row>*/}
                        </Col>
                        <Col xl={2} lg={2} md={12} sm={12} xs={12}>
                          <h4 className="price">
                            {" "}
                            {currency} {product.price}{" "}
                          </h4>
                        </Col>
                        <Col xl={2} lg={2} md={12} sm={12} xs={12}>
                          <FiTrash onClick={() => {
                            dispatch(
                                favoriteActions.removeProductFromFavorite(
                                    product.id,
                                    isUserLoggedIn(props.user.user)
                                )
                            );
                          }} size={22} style={{marginTop: 18, cursor: 'pointer', color: '#dd322b'}}/>
                        </Col>
                        <Col
                          xl={2}
                          lg={2}
                          md={12}
                          sm={12}
                          xs={12}
                          className="favorite-cart-btn"
                        >
                          {cartServices.isProductOnCart(
                            product.id,
                            props.cart.cart
                          ) ? (
                              <p
                                  className="cart-button"
                                  onClick={() => {
                                    dispatch(
                                        cartActions.removeFromCart(
                                            product.id,
                                            isUserLoggedIn(props.user.user)
                                        )
                                    );
                                  }}
                              >
                              <span className="before-click">
                                <span className="cart">
                                  <img
                                      className="cart-image"
                                      src={
                                        process.env.PUBLIC_URL +
                                        "/images/card-red.png"
                                      }
                                      alt=""
                                  />
                                </span>
                                <span className="cart responsive-width">
                                  Added
                                </span>
                              </span>
                              </p>
                          ) : (
                            <p
                              className="cart-button"
                              onClick={() => {
                                dispatch(
                                  cartActions.addProductToCart(
                                    product.id,
                                    isUserLoggedIn(props.user.user)
                                  )
                                );
                              }}
                            >
                              <span className="before-click">
                                <span className="cart">
                                  <img
                                    className="cart-image"
                                    src={
                                      process.env.PUBLIC_URL +
                                      "/images/card-red.png"
                                    }
                                    alt=""
                                  />
                                </span>
                                <span className="cart responsive-width">
                                  Add to Cart
                                </span>
                              </span>
                            </p>
                          )}
                        </Col>
                      </Row>
                    );
                  })
                ) : (
                  <div> No products on Favorite List </div>
                )}
                <br />
              </Col>
              <hr style={{ width: "100%" }} />
              <Col
                xl={12}
                lg={12}
                md={12}
                sm={12}
                xs={12}
                className="third-section"
              >
                <div>
                  <button
                    className="clear-all-btn cart-button"
                    onClick={() => {
                      dispatch(
                        favoriteActions.removeAllProductFromFavorite(
                          isUserLoggedIn(props.user.user)
                        )
                      );
                    }}
                  >
                    <span>Clear All</span>
                  </button>
                  <button
                    className="add-all-to-cart cart-button"
                    style={{width: "auto"}}
                    onClick={addAllToCart}
                  >
                    <span>
                      {" "}
                      <img src="/images/card-red.png" alt="" /> &nbsp; Add
                      All To Cart{" "}
                    </span>
                  </button>
                </div>
              </Col>
            </Row>
          </Col>
        </Row>
      </div>
    </div>
  );
};
const mapStateToProps = ({ user, cart, favorite }) => ({
  user,
  cart,
  favorite,
});
export default connect(mapStateToProps)(FavoriteProductList);
